@@ -10,7 +10,7 @@ import re
 
 __author__ = """Matt Burke"""
 __email__ = 'matttsburke@gmail.com'
-__version__ = '1.7.0'
+__version__ = '1.7.1'
 
 next_swipe = datetime.now
 visited_ids = []
@@ -53,7 +53,8 @@ def login(chromedriver, username, password, headless=False, login_url=default_lo
         browser.find_element_by_name("post").click()
         sleep(5)
         connected = True
-    except:
+    except Exception as e: 
+        print (e)
         connected = False
     return (connected)
 
@@ -158,14 +159,14 @@ def get_profile_data(id, like, screenshot_dir, photo_dir):
         nameandage=soup.title.string.split(" |")[0]
         profile_data["name"]=nameandage.split(",")[0]
         profile_data["age"]=nameandage.split(",")[1]
-    except:
-        pass
+    except Exception as e: 
+        print (e)
     try:
         location = soup.find('div', {
                          'class': "location-map-wrap__title js-location-label"}).text.rstrip('\n').strip()
         profile_data["location"] = location
-    except:
-        pass
+    except Exception as e: 
+        print (e)
   
     try:
         profile_data['online_status'] = soup.find('div', {
@@ -177,8 +178,8 @@ def get_profile_data(id, like, screenshot_dir, photo_dir):
         about = soup.find('div', {
                          'class': "profile-section__txt profile-section__txt--about"}).text.rstrip('\n').strip()
         profile_data["about"] = about
-    except:
-        pass
+    except Exception as e: 
+        print (e)
 
     try:
         for pers in soup.find_all('div', {'class': 'personal-info__item'}):
@@ -186,14 +187,14 @@ def get_profile_data(id, like, screenshot_dir, photo_dir):
                 'div', {'class': 'personal-info__label'}).text.rstrip('\n').strip())
             profile_data[label] = pers.find(
                 'div', {'class': 'personal-info__value'}).text.rstrip('\n').strip()
-    except:
-        pass
+    except Exception as e: 
+        print (e)
     try:
         languages = soup.find('div', {
                          'class': "profile__section js-profile-languages-container"}).text.rstrip('\n').strip()
         profile_data["languages"] = languages.replace('Languages', '').strip()
-    except:
-        pass
+    except Exception as e: 
+        print (e)
     try:
         interests = []
         for pers in soup.find_all('span', {'class': 'pill__text'}):
@@ -201,7 +202,8 @@ def get_profile_data(id, like, screenshot_dir, photo_dir):
         if interests:
             profile_data["interests"] = interests
         return profile_data
-    except:
+    except Exception as e: 
+        print (e)
         return False
 
 
@@ -221,8 +223,8 @@ def visit(id, like=False):
                 ".js-profile-header-more > .btn").click()
             sleep(7)
             browser.find_element_by_link_text("OK").click()
-        except:
-            pass
+        except Exception as e: 
+            print (e)
     return browser.page_source
 
 
@@ -235,7 +237,8 @@ def play_encounters(xtimes=10):
         if "You're out of votes!" in browser.page_source:
             try:
                 browser.find_element_by_tag_name("body").send_keys(Keys.ESCAPE)
-            except Exception:
+            except Exception as e: 
+                print (e)
                 return False
     return i
 
@@ -250,7 +253,8 @@ def send_message(id, msg):
         sleep(10)
         browser.find_element_by_id("t").send_keys(msg)
         browser.find_element_by_id("t").send_keys(Keys.RETURN)
-    except:
+    except Exception as e: 
+        print (e)
         return False
     return True
 
